pub struct AuthView {
pub active_sessions: HashMap<String, SessionInfo>,
pub pending_challenges: HashMap<String, ChallengeInfo>,
pub pending_recoveries: HashMap<String, RecoveryInfo>,
pub guardian_approvals: HashMap<String, Vec<AuthorityId>>,
pub recent_failures: Vec<FailureRecord>,
pub recent_recovery_failures: Vec<RecoveryFailureRecord>,
}Expand description
Aggregated authentication view state
This view represents the current authentication state for an authority, including active sessions, pending challenges, and recovery operations.
Fields
active_sessions: HashMap<String, SessionInfo>Active sessions indexed by session ID
pending_challenges: HashMap<String, ChallengeInfo>Pending challenges indexed by session ID
pending_recoveries: HashMap<String, RecoveryInfo>Pending recovery operations indexed by request ID
guardian_approvals: HashMap<String, Vec<AuthorityId>>Guardian approvals by request ID
recent_failures: Vec<FailureRecord>Recent authentication failures for rate limiting
recent_recovery_failures: Vec<RecoveryFailureRecord>Recent recovery failures and denials
Implementations
Sourceimpl AuthView
impl AuthView
Sourcepub fn is_session_active(&self, session_id: &str, now_ms: u64) -> bool
pub fn is_session_active(&self, session_id: &str, now_ms: u64) -> bool
Check if a session is active and not expired
Get all active sessions for an authority
Sourcepub fn is_recovery_approved(&self, request_id: &str) -> bool
pub fn is_recovery_approved(&self, request_id: &str) -> bool
Check if a recovery request has met its approval threshold
Sourcepub fn get_expired_sessions(&self, now_ms: u64) -> Vec<String>
pub fn get_expired_sessions(&self, now_ms: u64) -> Vec<String>
Get expired sessions that should be cleaned up
Sourcepub fn get_expired_challenges(&self, now_ms: u64) -> Vec<String>
pub fn get_expired_challenges(&self, now_ms: u64) -> Vec<String>
Get expired challenges that should be cleaned up
Sourcepub fn get_expired_recoveries(&self, now_ms: u64) -> Vec<String>
pub fn get_expired_recoveries(&self, now_ms: u64) -> Vec<String>
Get expired recovery requests that should be cleaned up